==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/PayDriver_ExpressCheckout.pm <==
package WebGUI::i18n::Spanish::PayDriver_ExpressCheckout;
use utf8;
our $I18N = {
  'api' => {
    'lastUpdated' => '1253801446',
    'message' => 'URL API'
  },
  'api error' => {
    'lastUpdated' => '1253801467',
    'message' => 'Error interactuando con el API PayPal: %s'
  },
  'api help' => {
    'lastUpdated' => '1253801495',
    'message' => 'Ingrese el URL base para el API NVP de PayPal'
  },
  'apiSandbox' => {
    'lastUpdated' => '1253801597',
    'message' => 'URL API Pruebas (<em>Sandbox</em>)'
  },
  'apiSandbox help' => {
    'lastUpdated' => '1253801580',
    'message' => 'Ingrese el URL hacia el API de pruebas (<em>sandbox</em>) PayPal.'
  },
  'currency' => {
    'lastUpdated' => '1253801668',
    'message' => 'Código de Moneda'
  },
  'currency help' => {
    'lastUpdated' => '1253801722',
    'message' => 'Ingrese el código alfanumérico de moneda PayPal (e.g. USD)'
  },
  'internal paypal error' => {
    'lastUpdated' => '1253802074',
    'message' => 'Error interno en PayPal.'
  },
  'name' => {
    'lastUpdated' => '1253802094',
    'message' => 'PayPal Express Checkout'
  },
  'password' => {
    'lastUpdated' => '1253802845',
    'message' => 'Contraseña PayPal'
  },
  'password help' => {
    'lastUpdated' => '1253802151',
    'message' => 'Ingrese la clave para PayPal'
  },
  'payment status' => {
    'lastUpdated' => '1253802174',
    'message' => 'Estado del Pago: %s'
  },
  'paypal' => {
    'lastUpdated' => '1253802529',
    'message' => 'URL a PayPal'
  },
  'paypal help' => {
    'lastUpdated' => '1253802557',
    'message' => 'Ingrese el URL a emplear para redirigir a PayPal.'
  },
  'sandbox' => {
    'lastUpdated' => '1253802600',
    'message' => 'URL de Pruebas (<em>sandbox</em>)'
  },
  'sandbox help' => {
    'lastUpdated' => '1253802623',
    'message' => 'Ingrese el URL a emplear para redirigir a PayPal en modo de pruebas.'
  },
  'signature' => {
    'lastUpdated' => '1253802856',
    'message' => 'Firma PayPal'
  },
  'signature help' => {
    'lastUpdated' => '1253802694',
    'message' => 'Firma tomada de las credenciales PayPal'
  },
  'testMode' => {
    'lastUpdated' => '1253802708',
    'message' => 'Modo Prueba'
  },
  'testMode help' => {
    'lastUpdated' => '1253802780',
    'message' => 'Indica si desea usar el SandBox de PayPal para hacer pruebas.'
  },
  'user' => {
    'lastUpdated' => '1253802820',
    'message' => 'Usuario PayPal'
  },
  'user help' => {
    'lastUpdated' => '1253802810',
    'message' => 'El usuario para ingresar a PayPal'
  }
}
;

1;

==> webgui_7.10.29.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/PayDriver_ExpressCheckout.pm <==
package WebGUI::i18n::Spanish::PayDriver_ExpressCheckout;
use utf8;
our $I18N = {
  'Pay' => {
    'lastUpdated' => '1276813425',
    'message' => 'Pagar'
  },
  'api' => {
    'lastUpdated' => '1253801446',
    'message' => 'URL API'
  },
  'api error' => {
    'lastUpdated' => '1253801467',
    'message' => 'Error interactuando con el API PayPal: %s'
  },
  'api help' => {
    'lastUpdated' => '1253801495',
    'message' => 'Ingrese el URL base para el API NVP de PayPal'
  },
  'apiSandbox' => {
    'lastUpdated' => '1253801597',
    'message' => 'URL API Pruebas (<em>Sandbox</em>)'
  },
  'apiSandbox help' => {
    'lastUpdated' => '1253801580',
    'message' => 'Ingrese el URL hacia el API de pruebas (<em>sandbox</em>) PayPal.'
  },
  'cart summary template' => {
    'lastUpdated' => '1276813441',
    'message' => 'Plantilla para Resumen de Carrito -- PayPal Express Checkout'
  },
  'currency' => {
    'lastUpdated' => '1253801668',
    'message' => 'Código de Moneda'
  },
  'currency help' => {
    'lastUpdated' => '1253801722',
    'message' => 'Ingrese el código alfanumérico de moneda PayPal (e.g. USD)'
  },
  'internal paypal error' => {
    'lastUpdated' => '1253802074',
    'message' => 'Error interno en PayPal.'
  },
  'name' => {
    'lastUpdated' => '1253802094',
    'message' => 'PayPal Express Checkout'
  },
  'password' => {
    'lastUpdated' => '1253802845',
    'message' => 'Contraseña PayPal'
  },
  'password help' => {
    'lastUpdated' => '1253802151',
    'message' => 'Ingrese la clave para PayPal'
  },
  'payment status' => {
    'lastUpdated' => '1253802174',
    'message' => 'Estado del Pago: %s'
  },
  'paypal' => {
    'lastUpdated' => '1253802529',
    'message' => 'URL a PayPal'
  },
  'paypal help' => {
    'lastUpdated' => '1253802557',
    'message' => 'Ingrese el URL a emplear para redirigir a PayPal.'
  },
  'sandbox' => {
    'lastUpdated' => '1253802600',
    'message' => 'URL de Pruebas (<em>sandbox</em>)'
  },
  'sandbox help' => {
    'lastUpdated' => '1253802623',
    'message' => 'Ingrese el URL a emplear para redirigir a PayPal en modo de pruebas.'
  },
  'signature' => {
    'lastUpdated' => '1253802856',
    'message' => 'Firma PayPal'
  },
  'signature help' => {
    'lastUpdated' => '1253802694',
    'message' => 'Firma tomada de las credenciales PayPal'
  },
  'summary template' => {
    'lastUpdated' => '1276813454',
    'message' => 'Plantilla para Resumen'
  },
  'summary template help' => {
    'lastUpdated' => '1276814494',
    'message' => 'Indique la plantilla a emplear para desplegar el resumen del carrito de compra, para que el usuario pueda confirmar el pago.'
  },
  'testMode' => {
    'lastUpdated' => '1253802708',
    'message' => 'Modo Prueba'
  },
  'testMode help' => {
    'lastUpdated' => '1253802780',
    'message' => 'Indica si desea usar el SandBox de PayPal para hacer pruebas.'
  },
  'user' => {
    'lastUpdated' => '1253802820',
    'message' => 'Usuario PayPal'
  },
  'user help' => {
    'lastUpdated' => '1253802810',
    'message' => 'El usuario para ingresar a PayPal'
  }
}
;

1;
